@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw( $VERSION );
-$VERSION = '0.0401';
+$VERSION = '0.0402';
 
 use Carp qw( croak );
 use DateTime;
@@ -536,6 +536,21 @@ DateTime::Format::Builder->create_class(
                     \&_add_day,
                 ],
             },
+
+            {
+                #hhmmss.ssZ 232030.5Z
+                #hh:mm:ss.ssZ 23:20:30.5Z
+                regex  => qr/^ T?? (\d\d) :?? (\d\d) :?? (\d\d) [\.,] (\d+) Z $/x,
+                params => [ qw( hour minute second nanosecond) ],
+                extra  => { time_zone => 'UTC' },
+                postprocess => [
+                    \&_add_year,
+                    \&_add_month,
+                    \&_add_day,
+                    \&_fractional_second
+                ],
+            },
+
             {
                 #hhmmZ 2320Z
                 #hh:mmZ 23:20Z
@@ -575,6 +590,21 @@ DateTime::Format::Builder->create_class(
                     \&_normalize_offset,
                 ],
             },
+            {
+                #hhmmss.ss[+-]hhmm 152746.5+0100 152746.5-0500
+                #hh:mm:ss.ss[+-]hh:mm 15:27:46.5+01:00 15:27:46.5-05:00
+                regex  => qr/^ T?? (\d\d) :?? (\d\d) :?? (\d\d) [\.,] (\d+)
+                            ([+-] \d\d :?? \d\d) $/x,
+                params => [ qw( hour minute second nanosecond time_zone ) ],
+                postprocess => [
+                    \&_add_year,
+                    \&_add_month,
+                    \&_add_day,
+                    \&_fractional_second,
+                    \&_normalize_offset,
+                ],
+            },
+
             {
                 #hhmmss[+-]hh 152746+01 152746-05
                 #hh:mm:ss[+-]hh 15:27:46+01 15:27:46-05
@@ -598,6 +628,17 @@ DateTime::Format::Builder->create_class(
                 params => [ qw( year month day hour minute second ) ],
                 extra  => { time_zone => 'floating' },
             },
+            {
+                #YYYYMMDDThhmmss.ss 19850412T101530.123
+                #YYYY-MM-DDThh:mm:ss.ss 1985-04-12T10:15:30.123
+                regex  => qr/^ (\d{4}) -??  (\d\d) -?? (\d\d)
+                            T (\d\d) :?? (\d\d) :?? (\d\d) [\.,] (\d+) $/x,
+                params => [ qw( year month day hour minute second nanosecond ) ],
+                extra  => { time_zone => 'floating' },
+                postprocess => [
+                    \&_fractional_second,
+                ],
+            },
             {
                 #YYYYMMDDThhmmssZ 19850412T101530Z
                 #YYYY-MM-DDThh:mm:ssZ 1985-04-12T10:15:30Z
@@ -607,6 +648,19 @@ DateTime::Format::Builder->create_class(
                 params => [ qw( year month day hour minute second ) ],
                 extra  => { time_zone => 'UTC' },
             },
+            {
+                #YYYYMMDDThhmmss.ssZ 19850412T101530.5Z 20041020T101530.5Z
+                #YYYY-MM-DDThh:mm:ss.ssZ 1985-04-12T10:15:30.5Z 1985-04-12T10:15:30.5Z
+                regex  => qr/^ (\d{4}) -??  (\d\d) -?? (\d\d)
+                            T?? (\d\d) :?? (\d\d) :?? (\d\d) [\.,] (\d+)
+                            Z$/x,
+                params => [ qw( year month day hour minute second nanosecond ) ],
+                extra  => { time_zone => 'UTC' },
+                postprocess => [
+                    \&_fractional_second,
+                ],
+            },
+
             {
                 #YYYYMMDDThhmmss[+-]hhmm 19850412T101530+0400
                 #YYYY-MM-DDThh:mm:ss[+-]hh:mm 1985-04-12T10:15:30+04:00
@@ -616,6 +670,19 @@ DateTime::Format::Builder->create_class(
                 params => [ qw( year month day hour minute second time_zone ) ],
                 postprocess => \&_normalize_offset,
             },
+            {
+                #YYYYMMDDThhmmss.ss[+-]hhmm 19850412T101530.5+0100 20041020T101530.5-0500
+                #YYYY-MM-DDThh:mm:ss.ss[+-]hh:mm 1985-04-12T10:15:30.5+01:00 1985-04-12T10:15:30.5-05:00
+                regex  => qr/^ (\d{4}) -??  (\d\d) -?? (\d\d)
+                            T?? (\d\d) :?? (\d\d) :?? (\d\d) [\.,] (\d+)
+                            ([+-] \d\d :?? \d\d) $/x,
+                params => [ qw( year month day hour minute second nanosecond time_zone ) ],
+                postprocess => [
+                    \&_fractional_second,
+                    \&_normalize_offset,
+                ],
+            },
+
             {
                 #YYYYMMDDThhmmss[+-]hh 19850412T101530+04
                 #YYYY-MM-DDThh:mm:ss[+-]hh 1985-04-12T10:15:30+04
